@@ -1,8 +1,8 @@
 /***************************************************************
- *                   Materials Object Library                  *
+ *                   Material Object Library                   *
  *     Class Eshelby : declaration for the Eshelby tensor      *
  *                    simula+@metz.ensam.fr                    *
- *		     GNU/linux version 0.1.0                   *
+ *		     GNU/linux version 0.1.8                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2005,2006 COLLARD Christophe
@@ -16,7 +16,7 @@
     \htmlonly 
     <FONT color="#838383">
 
-    Eshelby belongs to Materials Object Libraries (MateriOL++) </br>
+    Eshelby belongs to Material Object Libraries (MateriOL++) </br>
     MateriOL++ is part of Simula+ <br><br>
 
     Simula+ is free software; you can redistribute it and/or modify
@@ -37,12 +37,12 @@
     \endhtmlonly
 
     We note \f$ C \f$ the elasticity tensor (see \ref isotropic_tensor), \f$ T^{II} \f$ the interaction tensor (see \ref TII) and V the inclusion volume. Then, Eshelby tensor reads \n
-\f$ \displaystyle S^{II}_{ijkl} = \frac{1}{V} T^{II}_{ijpq} C_{pqkl} \f$.
+\f$ \displaystyle S^{II}_{ijkl} = T^{II}_{ijpq} C_{pqkl} \f$.
 
     \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
 	    copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.1.0
+    \version 0.1.8
     \date 2005-2006
     \bug none
     \warning none
@@ -68,8 +68,8 @@
 #include "../MOL++/tensors4.h"
 #endif
 
-#if !defined(__ISOTROPIC_TENSORS_H)
-#include "isotropic tensors.h"
+#if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
+#include "isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__TII_H)
@@ -87,11 +87,11 @@ class Eshelby
     Eshelby () {}   // default constructor
     ~Eshelby () {}  // destructor
 
-    template <class T> tensor4<T> Sii (const tensor4<T>&, const vector<T>&, int, int);
-    template <class T> tensor4<T> sphere (const isotropic_tensor<T>&);
-    template <class T> tensor4<T> penny_shape (const isotropic_tensor<T>&, const vector<T>&);
+    template <class T, template<class T> class tensor_type> tensor4<T> ellipsoid (const tensor_type<T>&, const vector<T>&, int, int);
+    template <class T> tensor4<T> sphere (const isotropic_elasticity_tensor<T>&);
+    template <class T> tensor4<T> penny_shape (const isotropic_elasticity_tensor<T>&, const vector<T>&);
     // computes interaction TII = T_2323 = T_2332 for spheroid oblates
-    template <class T> T oblate_spheroid_2332 (const isotropic_tensor<T>&, const vector<T>&);
+    template <class T> T oblate_spheroid_2332 (const isotropic_elasticity_tensor<T>&, const vector<T>&);
 };
 
 //=====Private methods for Eshelby==================================================
@@ -113,16 +113,16 @@ class Eshelby
   \return Eshelby tensor
 */
 
-//---------------------------------------------------------------------------------------------------------------
-template <class T> tensor4<T> Eshelby::Sii (const tensor4<T>& L, const vector<T>& geometry, int nItg1, int nItg2)
-//---------------------------------------------------------------------------------------------------------------
+//------------------------------------------------------------------------------------------------------
+template <class T, template<class T> class tensor_type>
+tensor4<T> Eshelby::ellipsoid (const tensor_type<T>& L, const vector<T>& geometry, int nItg1, int nItg2)
+//------------------------------------------------------------------------------------------------------
 {
   assert (geometry.dim() == 3);
 
-  T V_ = .75 /  (pi() * geometry[1] * geometry[2] * geometry[3]);
   TII<T> tii(nItg1,nItg2);
 
-  return V_ * (tii.Tii(L,geometry) || L);
+  return (tii.ellipsoid(L,geometry) || L);
 }
 
 
@@ -140,9 +140,9 @@ template <class T> tensor4<T> Eshelby::Sii (const tensor4<T>& L, const vector<T>
   \return Eshelby tensor
 */
 
-//--------------------------------------------------------------------------
-template <class T> tensor4<T> Eshelby::sphere (const isotropic_tensor<T>& C)
-//--------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class T> tensor4<T> Eshelby::sphere (const isotropic_elasticity_tensor<T>& C)
+//-------------------------------------------------------------------------------------
 {
   T nu = C.Poisson();
   T coef = 1/(15 * (1-nu));
@@ -175,9 +175,9 @@ template <class T> tensor4<T> Eshelby::sphere (const isotropic_tensor<T>& C)
   \return Eshelby tensor
 */
 
-//----------------------------------------------------------------------------------------------------------
-template <class T> tensor4<T> Eshelby::penny_shape (const isotropic_tensor<T>& C, const vector<T>& geometry)
-//----------------------------------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------------------------------------
+template <class T> tensor4<T> Eshelby::penny_shape (const isotropic_elasticity_tensor<T>& C, const vector<T>& geometry)
+//---------------------------------------------------------------------------------------------------------------------
 {
   assert (geometry.dim() == 3);
   assert (geometry[1] == geometry[2]);
@@ -213,9 +213,9 @@ template <class T> tensor4<T> Eshelby::penny_shape (const isotropic_tensor<T>& C
   \return Eshelby tensor coordiantes 2323 2332 3223 3232
 */
 
-//----------------------------------------------------------------------------------------------------------
-template <class T> T Eshelby::oblate_spheroid_2332 (const isotropic_tensor<T>& C, const vector<T>& geometry)
-//----------------------------------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------------------------------------
+template <class T> T Eshelby::oblate_spheroid_2332 (const isotropic_elasticity_tensor<T>& C, const vector<T>& geometry)
+//---------------------------------------------------------------------------------------------------------------------
 {
   assert (geometry.dim() == 3);
   assert (geometry[1] == geometry[2]);
