@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.1.0                   *
+ *	             GNU/linux version 0.1.8                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2005,2006 COLLARD Christophe
@@ -9,7 +9,7 @@
  ***************************************************************/
 
 /*
-    TII-tests belongs to Materials Object Libraries (MateriOL++)
+    TII-tests belongs to Material Object Libraries (MateriOL++)
     MateriOL++ is part of Simula+
 
     Simula+ is free software; you can redistribute it and/or modify
@@ -47,8 +47,8 @@
 #include <stdlib.h>
 #endif
 
-#if !defined(__PRECISION_H)
-#include "../../MOL++/precision.h"
+#if !defined(__PARAMETERS_H)
+#include "../../parameters.h"
 #endif
 
 #if !defined(__MATRIX_H)
@@ -59,8 +59,8 @@
 #include"../../MOL++/tensors4.h"
 #endif
 
-#if !defined(__ISOTROPIC_TENSORS_H)
-#include"../../MateriOL++/isotropic tensors.h"
+#if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
+#include"../../MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__TII_H)
@@ -83,12 +83,12 @@ int test_TII (int detail)
   long double V = 4/3. * pi() * power(R,3);
   long double lambda = 120000, mu = 80000, nu = 0.3;
 
-  isotropic_tensor<long double> C ("elasticity tensor");
+  isotropic_elasticity_tensor<long double> C ("elasticity tensor");
   C.Lame(lambda);
   C.Poisson(nu);
 
   tensor4<long double> T_analytique(3), Tiso_analytique(3);
-  long double coef = V / (30 * mu * (1-nu));
+  long double coef = 1 / (30 * mu * (1-nu));
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
       for (int k=1; k<=3; k++)
@@ -101,12 +101,12 @@ int test_TII (int detail)
 
   vector<long double> geometry(3,true,R); // a = b = c = R
   TII<long double> tii(15,30);
-  test = (Tiso_analytique == tii.sphere(C,geometry));
+  test = (Tiso_analytique == tii.sphere(C));
   if (detail) affiche ("sphere (analytique)", test);
   else result *= (test);
 
-  test = (tii.Tii(C,geometry) == tii.sphere(C,geometry));
-  if (detail) affiche ("Tii (sphere)", test);
+  test = (tii.ellipsoid(C,geometry) == tii.sphere(C));
+  if (detail) affiche ("ellipsoid (sphere)", test);
   else result *= (test);
 
   cout << endl;
